/* file.h -- Functions to manipulate (copy, move, etc.) files. */
/* $Id: file.h 207 2005-10-12 22:46:44Z rra $ */

#ifndef H_FILE
#define H_FILE

#include "config.h"
#include <stdio.h>
#include <sys/types.h>

/* Create a new file with the given name, owner, group, and permissions. */
extern bool create_file(const char *, uid_t, gid_t, mode_t);

/* Truncate an existing file and ensure the owner, group, and permissions. */
extern bool truncate_file(const char *, uid_t, gid_t, mode_t);

/* Given a file path, create the directory if it doesn't exist. */
extern void create_directory(char *path);

/* Copy a file from one location to another. */
extern bool copy(const char *sourcename, const char *destname);

/* Rename a log to a unique name, returning that name. */
extern char *rename_unique(const char *filename);

/* Rename files ending in a number and .gz or .bz2 as appropriate for the
   compression method, only keeping a given number. */
extern bool shuffle_files(const char *filename, int count);

#endif /* H_FILE */
