/* system.h -- System portability, included by all newsyslog source. */
/* $Id: system.h 156 2004-02-01 22:30:36Z eagle $ */

/* This header file should be included rather than config.h.  It takes care of
   including config.h, wraps it in include guards, and takes care of
   additional portability that configure determines is required. */

#ifndef H_SYSTEM
#define H_SYSTEM 1

#include "config.h"
#include <stdarg.h>             /* va_list */
#include <sys/types.h>          /* size_t */

/* __attribute__ is available in gcc 2.5 and later, but only with gcc 2.7
   could you use the __format__ form of the attributes, which is what we use
   (to avoid confusion with other macros). */
#ifndef __attribute__
# if __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 7)
#  define __attribute__(spec)   /* empty */
# endif
#endif

/* Used for unused parameters to silence gcc warnings. */
#define UNUSED  __attribute__((__unused__))

/* Make sure that the bool type and its associated constants are available. */
#if HAVE_STDBOOL_H
# include <stdbool.h>
#else
# if !HAVE__BOOL
#  ifdef __cplusplus
typedef bool _Bool;
#  else
typedef unsigned char _Bool;
#  endif
# endif
# define bool _Bool
# define false 0
# define true 1
# define __bool_true_false_are_defined 1
#endif

/* Make sure that snprintf and vsnprintf are declared. */
#if !HAVE_DECL_SNPRINTF
extern int snprintf(char *, size_t, const char *, ...)
    __attribute__((__format__(3, 4)));
#endif
#if !HAVE_DECL_VSNPRINTF
extern int vsnprintf(char *, size_t, const char *, va_list);
#endif

#endif /* H_SYSTEM */
